.. fairly documentation master file, created by
   sphinx-quickstart on Mon Oct  3 21:00:21 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Fairly Toolset Documentation
==================================

.. toctree::
   :maxdepth: 2
   :caption: Fairly Package

   installation

.. toctree::
   :maxdepth: 1
   :caption: Tutorials

   tutorials/jupyterlab
   tutorials/cli
   tutorials/python-api

.. toctree::
   :maxdepth:  1
   :caption: Fairly API
   
   modules
   api/fairly.client
   api/fairly.dataset
   api/fairly.file


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
